package Hawat::Controller::Devel;
use strict;
use warnings;
use Moose;
use namespace::autoclean;

use Data::Dumper;
use Mentat::Core qw(:c_hawat);

use Chart::Palette;

#-------------------------------------------------------------------------------
# Initialization section
#-------------------------------------------------------------------------------

BEGIN { extends 'Hawat::Controller::Secure'; }

__PACKAGE__->config(
    class       => 'Hawat::Controller::Devel',
    constructor => 'new',
);

use constant SELECTORS_CACHE_REWRITE => 0; # Grow up mongodb performance !!!
use constant SELECTORS_STAT_ONLY     => 1; # Grow up mongodb performance !!!

=head1 NAME

Hawat::Controller::Devel - Catalyst controller for system administration

=head1 DESCRIPTION

Catalyst controller for handling actions related to system administration.

=head1 METHODS

=cut

#-------------------------------------------------------------------------------
# Implementation section
#-------------------------------------------------------------------------------

=head2 index

=cut

sub index :Path :Args(0) {
    my ( $self, $c ) = @_;
    $c->response->redirect($c->uri_for($self->action_for('dashboard')));
}

=head2 dashboard

Development dashboard

=cut

sub dashboard :Local :Args(0) {
    my ($self, $c) = @_;

    my $item_sets = $c->model('Devel')->get_item_sets(SELECTORS_CACHE_REWRITE(), SELECTORS_STAT_ONLY());
    $c->stash(item_sets => $item_sets);

    $c->stash(chart_palette => Chart::Palette->palette());

    # Optionally dump interesting variables - dependent on the devel switch
    $self->dump_variable($c, 'Stash', $c->stash) if $c->cfg('devel');
}

=head1 AUTHOR

 Jan Mach
 Cesnet, z.s.p.o
 jan.mach@cesnet.cz
 http://www.cesnet.cz

=head1 LICENSE

This library is free software. You can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

__PACKAGE__->meta->make_immutable;

1;
