package Hawat::Controller::Help;
use strict;
use warnings;
use Moose;
use namespace::autoclean;

use Data::Dumper;
use Mentat::Core qw(:c_hawat);

#-------------------------------------------------------------------------------
# Initialization section
#-------------------------------------------------------------------------------

BEGIN { extends 'Hawat::Controller::Secure'; }

__PACKAGE__->config(
    class       => 'Hawat::Controller::Help',
    constructor => 'new',
);

=head1 NAME

Hawat::Controller::Help - Catalyst controller for built-in system help

=head1 DESCRIPTION

Catalyst controller for handling actions related to built-in system help

=head1 METHODS

=cut

#-------------------------------------------------------------------------------
# Implementation section
#-------------------------------------------------------------------------------

=head2 index

=cut

sub index :Path :Args(0) {
    my ( $self, $c ) = @_;
    $c->response->redirect($c->uri_for($self->action_for('browse')));
}

=head2 browse

Browse built-in help

=cut

sub browse :Local :Args(0) {
    my ($self, $c) = @_;

    # TODO: make use of 'nowrap' for ajax queries
    #$c->stash(nowrap => 1);

    # Optionally dump interesting variables - dependent on the devel switch
    $self->dump_variable($c, 'Stash', $c->stash) if $c->cfg('devel');

    # Render the view
    # NOTE: No need for that now, it will be rendered automagically, when the
    # 'end' method is called (see the Hawat::Controller::Secure for details)
    #$c->forward($c->view(HAWAT_VIEW_HTML));
}

=head1 AUTHOR

 Jan Mach
 Cesnet, z.s.p.o
 jan.mach@cesnet.cz
 http://www.cesnet.cz

=head1 LICENSE

This library is free software. You can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

__PACKAGE__->meta->make_immutable;

1;
