package Hawat::Controller::Statistics;
use strict;
use warnings;
use Moose;
use namespace::autoclean;

use Data::Dumper;
use Mentat::Core qw(:c_hawat);

#-------------------------------------------------------------------------------
# Initialization section
#-------------------------------------------------------------------------------

BEGIN { extends 'Hawat::Controller::Secure'; }

__PACKAGE__->config(
    class       => 'Hawat::Controller::Statistics',
    constructor => 'new',
);

=head1 NAME

Hawat::Controller::Statistics - Catalyst controller for processing statistics

=head1 DESCRIPTION

Catalyst controller for handling actions related to processing statistics

=head1 METHODS

=cut

#-------------------------------------------------------------------------------
# Implementation section
#-------------------------------------------------------------------------------

=head2 index

Default controller action, redirects to the 'list' action

=cut

sub index :Path :Args(0) {
    my ( $self, $c ) = @_;
    $c->response->redirect($c->uri_for($self->action_for('list')));
}

=head2 list

Display all processing statistic charts

=cut

sub list :Local :Args(0) {
    my ($self, $c) = @_;

    my $stats_dir = $c->cfg('stats_dir');

    my ($count, $charts) = $c->model('Statistics')->get_stats_proc($stats_dir);

    # Retrieve the names of all image files containing the statistics
    $c->stash(count => $count, charts => $charts);
    $c->stash(msg_error => "No charts were found in data storage") unless $count;

    # Render the view
    # NOTE: No need for that now, it will be rendered automagically, when the
    # 'end' method is called (see the Hawat::Controller::Secure for details)
    #$c->forward($c->view(HAWAT_VIEW_HTML));
}

=head1 AUTHOR

 Jan Mach
 Cesnet, z.s.p.o
 jan.mach@cesnet.cz
 http://www.cesnet.cz

=head1 LICENSE

This library is free software. You can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

__PACKAGE__->meta->make_immutable;

1;
