package Hawat::Model::Devel;
use strict;
use warnings;
use Moose;
use namespace::autoclean;

use Carp;
use Scalar::Util 'blessed';
use Time::HiRes qw (time);
use HTML::Entities;

use Data::Dumper;
use Mentat::Core qw(:c_hawat);
use Mentat::Storage::Mongo::Aggregator;

#-------------------------------------------------------------------------------
# Initialization section
#-------------------------------------------------------------------------------

# Define meaningful default configuration values
use constant DFLT_FLAG_DEVEL => 0;

use constant UNDISCLOSED => "Undisclosed";
use constant MODEL_QUERY => "Query";

BEGIN { extends 'Catalyst::Model::Adaptor'; }

__PACKAGE__->config(
    class            => 'Hawat::Model::Devel',
    constructor      => 'new',
    devel            => 0,
    database_name    => 'mentat',
    collection_name  => 'alerts',
    sdatabase_name   => 'mentat_stats',
    scollection_name => 'statistics',
    cache_dir        => '/var/mentat/cache',
    cache_ttl        => 60*60*24*7,
);
has "devel"            => (is => 'ro', isa => 'Bool', required => 1);
has "database_name"    => (is => 'ro', isa => 'Str',  required => 1);
has "collection_name"  => (is => 'ro', isa => 'Str',  required => 1);
has "sdatabase_name"   => (is => 'ro', isa => 'Str',  required => 1);
has "scollection_name" => (is => 'ro', isa => 'Str',  required => 1);
has "cache_dir"        => (is => 'ro', isa => 'Str',  required => 1);
has "cache_ttl"        => (is => 'ro', isa => 'Int',  required => 1);
has "aggregator"       => (is => 'rw', isa => 'Mentat::Storage::Mongo::Aggregator');

#-------------------------------------------------------------------------------
# Implementation section
#-------------------------------------------------------------------------------

sub get_item_sets($;$$)
{
    my $self = shift;
    my ($rewrite, $stats_only) = @_;
    confess "Instance method not invoked on object instance" unless blessed($self);
    return $self->aggregator->get_item_sets($rewrite, $stats_only);
}

#-------------------------------------------------------------------------------

# BUILD()
#
#  Purpose : Perform additional instance setup after the object is created
#  Comment : Callback method, see Moose::Manual::Construction(3) for details

sub BUILD {
    my $self = shift;

    # Initialize the internal helper objects for whole model
    $self->aggregator(Mentat::Storage::Mongo::Aggregator->new(
        database    => $self->database_name,
        collection  => $self->collection_name,
        sdatabase   => $self->sdatabase_name,
        scollection => $self->scollection_name,
        cache       => $self->cache_dir,
        ttl         => $self->cache_ttl,
    ));

    # If you use 'weak_ref' for moose attribute, previous calls will not set the
    # attributes. It is necessary to do it with antermediate variables $self->db($r);
    die "Unable to initialize database aggregator attribute\n" unless $self->aggregator;
}

# COMPONENT
#
#  Purpose : Perform additional instance setup after the object is created
#  Comment : Callback method, see Catalyst::Component(3) for details
#
#  FIXME: For some reason config merging does not work without this code present
#         in the package!!!

sub COMPONENT {
    my ($class, $app, $args) = @_;
    $args = $class->merge_config_hashes($class->config, $args);
    #use Data::Dumper;
    #$app->log->debug("X $class: " . Dumper($class->config));
    #$app->log->debug("Y args  : " . Dumper($args));
    #$app->log->debug("Z $app  : " . Dumper($app->config));
    #$app->log->debug("MERGE XY: " . Dumper($args));
    return $class->new($app, $args);
}

1;
